@@ -14,10 +14,7 @@ import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/identity",
-    "0.0.96",
-    __name__[0:-6],
-    "identity@0.0.96.jsii.tgz",
+    "@aws-prototyping-sdk/identity", "0.2.2", __name__[0:-6], "identity@0.2.2.jsii.tgz"
 )
 
 __all__ = [
